#
# spec file for package MultiMarkdown-5
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           MultiMarkdown-5
Version:        5.4.0
Release:        14.2
Summary:        Reference implementation of MultiMarkdown
License:        MIT
Group:          Productivity/Publishing/Other
Url:            http://fletcherpenney.net/multimarkdown
# We have to use tarball generated via _service as released ones are
# missing submodules that are necessary for building
Source:         %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
Conflicts:      MultiMarkdown-6
Provides:       markdown
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
MultiMarkdown is a derivative of Markdown that adds new syntax features,
such as footnotes, tables, and metadata. Additionally, it offers mechanisms
to convert plain text into LaTeX in addition to HTML.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -fPIE -D_GNU_SOURCE"
export CXXLAGS="%{optflags} -fPIE -D_GNU_SOURCE"
# Build will fail when this file is not present - build system will try to
# generate this file using MultiMarkdown which is not yet built
install -D /dev/null build/README.html
make %{?_smp_mflags} XFLAGS="%{optflags}" -C submodules/greg
%cmake
%make_jobs

%install
%cmake_install
# Avoid conflict with mtools
mv %{buildroot}%{_bindir}/mmd  %{buildroot}%{_bindir}/%{name}-mmd
# multimarkdown is provided by other packages thus we use
# update-alternatives
mv %{buildroot}%{_bindir}/markdown %{buildroot}%{_bindir}/%{name}-markdown
install -d %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/markdown
ln -sf %{_sysconfdir}/alternatives/markdown %{buildroot}%{_bindir}/markdown

%check
%ctest

%post
update-alternatives \
	--install %{_bindir}/markdown markdown %{_bindir}/%{name}-markdown 30

%postun
if [ ! -f %{_bindir}/%{name}-markdown ] ; then
	update-alternatives --remove markdown %{_bindir}/%{name}-markdown
fi

%files
%doc LICENSE.txt README.md CHANGELOG.md
%ghost %{_sysconfdir}/alternatives/markdown
%{_bindir}/markdown
%{_bindir}/%{name}-markdown
%{_bindir}/%{name}-mmd
%{_bindir}/mmd2all
%{_bindir}/mmd2odf
%{_bindir}/mmd2opml
%{_bindir}/mmd2pdf
%{_bindir}/mmd2rtf
%{_bindir}/mmd2tex
%{_bindir}/multimarkdown

%changelog
* Fri Nov  3 2017 mpluskal@suse.com
- Conflict with MultiMarkdown-6
- Provide virtual package markdown
- Small spec file cleanup
* Thu Jun 22 2017 mpluskal@suse.com
- Enable tests
- Update alernatives handling according to current guidelines
* Fri Oct 28 2016 mpluskal@suse.com
- Fix typo and add more comments
* Tue Oct 18 2016 mpluskal@suse.com
- Use update alternatives to allow parallel installation with discount
- Avoid conflict with mtools
* Sun Oct 16 2016 mpluskal@suse.com
- Update to version 5.4.0:
  * Improve accuracy and performance of strong/emph
  * CHANGED: Update greg
  * 5.3.0
  * CHANGED: Update README
  * ADDED: Move static library options to separate make target
  * FIXED: Fix crash with empty table label
  * ADDED: Add email address to cpack settings (addresses #31)
  * CHANGED: Increase list of syntax structures that are evaluated for abbreviations (Thanks, David!)
  * FIXED: Avoids problem mentioned on github (#30), but doesn't actually solve it. Any help appreciated!
  * version bump 5.4.0
* Sat Jul  9 2016 mpluskal@suse.com
- Update to version 5.3.0:
  * FIXED: Don't allow math spans inside strong/emph
  * FIXED: Fix slow parsing of complex strong/emph (Fixes #18)
  * CHANGED: Update test suite
  * FIXED: Improve performance; FIXED: Fix additional edge case in emph/strong parser
  * Improve accuracy and performance of strong/emph
  * CHANGED: Update greg
  * 5.3.0
* Wed Jul  6 2016 mpluskal@suse.com
- Fix building on linux (needs static glibc and -D_GNU_SOURCE)
* Sun May  1 2016 mpluskal@suse.com
- Update to version 5.2.0:
  * ADDED: Add support for 'HTML FOOTER' metadata -- appended at very end of HTML documents (after footnotes)
  * CHANGED: Update documentation for HTML Footer metadata
  * CHANGED: Update Math test suite
  * FIXED: Improve accuracy of strong/emph parsing; CHANGED: Allow nested strong/emph spans (though effect of output is not defined for all formats)
  * ADDED: Add additional test cases
  * CHANGED: recursive support for CriticMarkup syntax (e.g. an addition can be included inside a substitution).
  * FIXED: Remove debugging statement in recent CriticMarkup changes
  * CHANGED: Update test suite
  * Version bump 5.2.0
* Sun May  1 2016 mpluskal@suse.com
- Initial package
